package com.jobs.common;


import io.jsonwebtoken.*;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.RandomStringUtils;
import org.springframework.util.StringUtils;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

public class JobsUtils {

    /**
     * 获取一个字符串的 md5 值
     */
    public String getMd5(String str) {
        if (!StringUtils.isEmpty(str)) {
            return DigestUtils.md5Hex(str);
        }

        return null;
    }

    /**
     * 生成一个 jwt token
     *
     * @param data   要存入 token 中的数据
     * @param secret 数据校验的密钥
     * @param second 设置 token 的有效期（秒）
     * @return
     */
    public String getToken(Map data, String secret, Integer second) {
        long currentTime = System.currentTimeMillis();
        return Jwts.builder()
                .signWith(SignatureAlgorithm.HS512, secret)
                .setExpiration(new Date(currentTime + second * 1000))
                .addClaims(data)
                .compact();
    }

    /**
     * 获取 jwt token 中存储的键值对数据
     */
    public Map getClaims(String token, String secret) {
        try {
            return Jwts.parser()
                    .setSigningKey(secret)
                    .parseClaimsJws(token).getBody();
        } catch (Exception ex) {
            //无效的 jwt token，要么已经过期，要么被篡改了不合法
            System.out.println(ex.getMessage());
            Map map = new HashMap();
            map.put("info", ex.getMessage());
            return map;
        }
    }

    /**
     * 获取指定位数的随机数字字符串
     *
     * @param len 指定位数长度，例如 6 位数字
     */
    public String getRandomNumber(Integer len) {
        if (len > 0) {
            String result = RandomStringUtils.randomNumeric(len);
            return result;
        }

        return null;
    }
}
